@@ -18,8 +18,7 @@ class ZmqBase:
     RPC_PARAMETERS = 'parameters'
 
     STATUS_CODE_BAD_SERIALIZATION = 400
-    STATUS_CODE_MISSING_FUNCTION = 450
-    STATUS_CODE_BAD_FUNCTION = 451
+    STATUS_CODE_BAD_SERVICE = 451
     STATUS_CODE_EXCEPTION_RAISED = 463
     STATUS_CODE_PROXY_ERROR = 482
 
